@@ -1,12 +1,13 @@
 # -*- coding: utf-8 -*-
 import copy
 from django.core.paginator import Paginator
-from django.db.models.query import QuerySet
 from django.http import Http404
 from django.utils.datastructures import SortedDict
-from django.template import Context
+from django.template import RequestContext
 from django.template.loader import get_template
+from django.test.client import RequestFactory
 from django.utils.encoding import StrAndUnicode
+import sys
 from .utils import Accessor, AttributeDict, OrderBy, OrderByTuple, Sequence
 from .rows import BoundRows, BoundRow
 from .columns import BoundColumns, Column
@@ -24,14 +25,19 @@ class TableData(object):
     input table data.
     """
     def __init__(self, data, table):
-        if isinstance(data, QuerySet):
-            self.queryset = data
-        elif isinstance(data, list):
-            self.list = data[:]
-        else:
-            raise ValueError('data must be a list or QuerySet object, not %s'
-                             % data.__class__.__name__)
         self._table = table
+        # data may be a QuerySet-like objects with count() and order_by()
+        if (hasattr(data, 'count') and callable(data.count) and
+            hasattr(data, 'order_by') and callable(data.order_by)):
+            self.queryset = data
+        # otherwise it must be convertable to a list
+        else:
+            try:
+                self.list = list(data)
+            except:
+                raise ValueError('data must be QuerySet-like (have count and '
+                                 'order_by) or support list(data) -- %s is '
+                                 'neither' % data.__class__.__name__)
 
     def __len__(self):
         # Use the queryset count() method to get the length, instead of
@@ -156,64 +162,69 @@ class TableOptions(object):
         self.sequence = Sequence(getattr(options, "sequence", ()))
         self.sortable = getattr(options, "sortable", True)
         self.model = getattr(options, "model", None)
+        self.template = getattr(options, "template", "django_tables2/table.html")
 
 
 class Table(StrAndUnicode):
     """
     A collection of columns, plus their associated data rows.
 
-    :type attrs: ``dict``
+    :type  attrs: dict
     :param attrs: A mapping of attributes to values that will be added to the
             HTML ``<table>`` tag.
 
-    :type data:  ``list`` or ``QuerySet``
+    :type  data:  list or QuerySet-like
     :param data: The :term:`table data`.
 
-    :type exclude: *iterable*
+    :type  exclude: iterable
     :param exclude: A list of columns to be excluded from this table.
 
-    :type order_by: ``None``, ``tuple`` or ``string``
+    :type  order_by: None, tuple or string
     :param order_by: sort the table based on these columns prior to display.
             (default :attr:`.Table.Meta.order_by`)
 
-    :type order_by_field: ``string`` or ``None``
+    :type  order_by_field: string or None
     :param order_by_field: The name of the querystring field used to control
             the table ordering.
 
-    :type page_field: ``string`` or ``None``
+    :type  page_field: string or None
     :param page_field: The name of the querystring field used to control which
             page of the table is displayed (used when a table is paginated).
 
-    :type per_page_field: ``string`` or ``None``
+    :type  per_page_field: string or None
     :param per_page_field: The name of the querystring field used to control
             how many records are displayed on each page of the table.
 
-    :type prefix: ``string``
+    :type  prefix: string
     :param prefix: A prefix used on querystring arguments to allow multiple
             tables to be used on a single page, without having conflicts
             between querystring arguments. Depending on how the table is
             rendered, will determine how the prefix is used. For example ``{%
             render_table %}`` uses ``<prefix>-<argument>``.
 
-    :type sequence: *iterable*
+    :type  sequence: iterable
     :param sequence: The sequence/order of columns the columns (from left to
             right). Items in the sequence must be column names, or the
             *remaining items* symbol marker ``"..."`` (string containing three
             periods). If this marker is used, not all columns need to be
             defined.
 
-    :type sortable: ``bool``
+    :type  sortable: bool
     :param sortable: Enable/disable sorting on this table
 
-    :type empty_text: ``string``
+    :type  template: string
+    :param template: the template to render when using {% render_table %}
+            (default ``django_tables2/table.html``)
+
+    :type  empty_text: string
     :param empty_text: Empty text to render when the table has no data.
             (default :attr:`.Table.Meta.empty_text`)
 
     The ``order_by`` argument is optional and allows the table's
-    ``Meta.order_by`` option to be overridden. If the ``order_by is None``
+    ``Meta.order_by`` option to be overridden. If  ``order_by`` is ``None``
     the table's ``Meta.order_by`` will be used. If you want to disable a
     default ordering, simply use an empty ``tuple``, ``string``, or ``list``,
-    e.g. ``Table(…, order_by='')``.
+    e.g. ``Table(..., order_by='')``.
 
 
     Example:
@@ -233,7 +244,8 @@ class Table(StrAndUnicode):
 
     def __init__(self, data, order_by=None, sortable=None, empty_text=None,
                  exclude=None, attrs=None, sequence=None, prefix=None,
-                 order_by_field=None, page_field=None, per_page_field=None):
+                 order_by_field=None, page_field=None, per_page_field=None,
+                 template=None):
         self.rows = BoundRows(self)
         self.columns = BoundColumns(self)
         self.data = self.TableDataClass(data=data, table=self)
@@ -254,6 +266,7 @@ class Table(StrAndUnicode):
             self.order_by = self._meta.order_by
         else:
             self.order_by = order_by
+        self.template = template
 
     def __unicode__(self):
         return unicode(repr(self))
@@ -262,13 +275,13 @@ class Table(StrAndUnicode):
         """
         Render the table to a simple HTML table.
 
-        The rendered table won't include pagination or sorting, as those
-        features require a RequestContext. Use the ``render_table`` template
-        tag (requires ``{% load django_tables2 %}``) if you require this extra
-        functionality.
+        If this method is used in the request/response cycle, any links
+        generated will clobber the querystring of the request. Use the
+        ``{% render_table %}`` template tag instead.
         """
-        template = get_template('django_tables2/basic_table.html')
-        return template.render(Context({'table': self}))
+        request = RequestFactory().get('/')
+        template = get_template(self.template)
+        return template.render(RequestContext(request, {'table': self}))
 
     @property
     def attrs(self):
@@ -351,10 +364,15 @@ class Table(StrAndUnicode):
         :param page: which page should be displayed.
         """
         self.paginator = klass(self.rows, per_page, *args, **kwargs)
-        try:
-            self.page = self.paginator.page(page)
-        except Exception as e:
-            raise Http404(str(e))
+        self._page_number = page
+
+    @property
+    def page(self):
+        if hasattr(self, '_page_number'):
+            try:
+                return self.paginator.page(self._page_number)
+            except:
+                raise Http404(sys.exc_info()[1])
 
     @property
     def per_page_field(self):
@@ -406,3 +424,12 @@ class Table(StrAndUnicode):
     @sortable.setter
     def sortable(self, value):
         self._sortable = value
+
+    @property
+    def template(self):
+        return (self._template if self._template is not None
+                               else self._meta.template)
+
+    @template.setter
+    def template(self, value):
+        self._template = value
